
//
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
// 
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
//

// This source file was created by a code generator.
// Please do not edit.

#include "QmfPackage.h"
#include <qmf/Schema.h>
#include <qmf/SchemaProperty.h>
#include <qmf/SchemaMethod.h>
#include <string>

using namespace std;
using namespace qmf::org::libvirt;

void PackageDefinition::configure(::qmf::AgentSession& session)
{
    string package("org.libvirt");

    //
    // Data: Node
    //
    data_Node = qmf::Schema(SCHEMA_TYPE_DATA, package, "Node");
    {
        qmf::SchemaProperty prop("hostname", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setIndex(true);
        prop.setDesc("Host name");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("uri", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("URI of libvirt");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("libvirtVersion", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Version of libvirt on the managed node");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("apiVersion", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Version of libvirt API on the managed node");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("hypervisorVersion", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Hypervisor Version");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("hypervisorType", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Hypervisor type");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("model", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("CPU Model");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("memory", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Host memory");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("cpus", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Number of CPUS");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("mhz", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("MHz of CPUs");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("nodes", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Number of NUMA cells.");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("sockets", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Number of CPU Sockets per node");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("cores", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Number of cores per socket");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("threads", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Number of threads per core");
        data_Node.addProperty(prop);
    }

    {
        qmf::SchemaMethod method("domainDefineXML");
        method.setDesc("Define a new domain, but does not start it.");
        {
            qmf::SchemaProperty arg("xmlDesc", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("XML domain description");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("domain", qmf::SCHEMA_DATA_MAP);
            arg.setSubtype("reference");
            arg.setDesc("Newly created domain object");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Node.addMethod(method);
    }

    {
        qmf::SchemaMethod method("storagePoolDefineXML");
        method.setDesc("Define a new inactive storage pool based on its XML description. The pool is persistent, until explicitly undefined.");
        {
            qmf::SchemaProperty arg("xmlDesc", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("XML Description of the storage pool");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("pool", qmf::SCHEMA_DATA_MAP);
            arg.setSubtype("reference");
            arg.setDesc("Newly created storage pool");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Node.addMethod(method);
    }

    {
        qmf::SchemaMethod method("findStoragePoolSources");
        method.setDesc("Talks to a storage backend and attempts to auto-discover the set of available storage pool sources.");
        {
            qmf::SchemaProperty arg("type", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Type of storage pool sources to discover.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("srcSpec", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("XML document specifying discovery source");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("xmlDesc", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("XML document consisting of a SourceList element containing a source document appropriate to the given pool type for each discovered source.");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Node.addMethod(method);
    }

    {
        qmf::SchemaMethod method("storagePoolCreateXML");
        method.setDesc("Create a new storage based on its XML description. The pool is not persistent, so its definition will disappear when it is destroyed, or if the host is restarted");
        {
            qmf::SchemaProperty arg("xmlDesc", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("XML Description of the storage pool");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("pool", qmf::SCHEMA_DATA_MAP);
            arg.setSubtype("reference");
            arg.setDesc("Newly created storage pool");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Node.addMethod(method);
    }

    session.registerSchema(data_Node);

    //
    // Data: Domain
    //
    data_Domain = qmf::Schema(SCHEMA_TYPE_DATA, package, "Domain");
    {
        qmf::SchemaProperty prop("uuid", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setIndex(true);
        prop.setDesc("Domain UUID");
        data_Domain.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("name", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setIndex(true);
        prop.setDesc("Domain name");
        data_Domain.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("id", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Hypervisor Domain id, -1 if not running.");
        data_Domain.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("node", qmf::SCHEMA_DATA_MAP);
        prop.setSubtype("reference");
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Node of this VM");
        data_Domain.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("state", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Domain state.");
        data_Domain.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("numVcpus", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Number of virtual CPUs.");
        data_Domain.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("active", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("true/false domain active.");
        data_Domain.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("maximumMemory", qmf::SCHEMA_DATA_INT);
        prop.setDesc("Maximum memory allowed in KB.");
        data_Domain.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("memory", qmf::SCHEMA_DATA_INT);
        prop.setDesc("Memory used in KB.");
        data_Domain.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("cpuTime", qmf::SCHEMA_DATA_INT);
        prop.setDesc("CPU time used in nanoseconds.");
        data_Domain.addProperty(prop);
    }

    {
        qmf::SchemaMethod method("create");
        method.setDesc("Start stopped VM");
        data_Domain.addMethod(method);
    }

    {
        qmf::SchemaMethod method("destroy");
        method.setDesc("Stop this VM");
        data_Domain.addMethod(method);
    }

    {
        qmf::SchemaMethod method("undefine");
        method.setDesc("Undefine the domain");
        data_Domain.addMethod(method);
    }

    {
        qmf::SchemaMethod method("suspend");
        method.setDesc("Suspend this VM");
        data_Domain.addMethod(method);
    }

    {
        qmf::SchemaMethod method("resume");
        method.setDesc("Resume suspended VM");
        data_Domain.addMethod(method);
    }

    {
        qmf::SchemaMethod method("save");
        method.setDesc("Save this VM");
        {
            qmf::SchemaProperty arg("filename", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Name of file to save VM image in");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        data_Domain.addMethod(method);
    }

    {
        qmf::SchemaMethod method("restore");
        method.setDesc("Restore saved VM");
        {
            qmf::SchemaProperty arg("filename", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Name of file to restore from");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        data_Domain.addMethod(method);
    }

    {
        qmf::SchemaMethod method("shutdown");
        method.setDesc("Shutdown a VM");
        data_Domain.addMethod(method);
    }

    {
        qmf::SchemaMethod method("reboot");
        method.setDesc("Reboot VM");
        data_Domain.addMethod(method);
    }

    {
        qmf::SchemaMethod method("getXMLDesc");
        method.setDesc("Return an XML description of the domain.");
        {
            qmf::SchemaProperty arg("description", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("XML description of the domain.");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Domain.addMethod(method);
    }

    {
        qmf::SchemaMethod method("migrate");
        method.setDesc("Migrate this VM to another host");
        {
            qmf::SchemaProperty arg("destinationUri", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Destination host connection uri.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("flags", qmf::SCHEMA_DATA_INT);
            arg.setDesc("Flags for migration, see documentation for details.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("newDomainName", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("New domain name on new host if applicable.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("uri", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("Destination hostname/URI as seen from host.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("bandwidth", qmf::SCHEMA_DATA_INT);
            arg.setDesc("Maximum bandwidth to consume in Mbps.");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        data_Domain.addMethod(method);
    }

    session.registerSchema(data_Domain);

    //
    // Data: Pool
    //
    data_Pool = qmf::Schema(SCHEMA_TYPE_DATA, package, "Pool");
    {
        qmf::SchemaProperty prop("uuid", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setIndex(true);
        prop.setDesc("Pool UUID");
        data_Pool.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("name", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setIndex(true);
        prop.setDesc("Pool name");
        data_Pool.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("parentVolume", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("If this pool is an LVM pool, this will contain the parent volume path.");
        data_Pool.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("state", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Pool state");
        data_Pool.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("capacity", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Pool size in bytes");
        data_Pool.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("allocation", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Current allocation in bytes");
        data_Pool.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("available", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Available space in bytes");
        data_Pool.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("node", qmf::SCHEMA_DATA_MAP);
        prop.setSubtype("reference");
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Node of this storage pool");
        data_Pool.addProperty(prop);
    }

    {
        qmf::SchemaMethod method("getXMLDesc");
        method.setDesc("Return an XML description of the storage pool.");
        {
            qmf::SchemaProperty arg("description", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("XML description of the storage pool.");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Pool.addMethod(method);
    }

    {
        qmf::SchemaMethod method("create");
        method.setDesc("Starts an inactive storage pool.");
        data_Pool.addMethod(method);
    }

    {
        qmf::SchemaMethod method("build");
        method.setDesc("Build the underlying storage pool.");
        data_Pool.addMethod(method);
    }

    {
        qmf::SchemaMethod method("destroy");
        method.setDesc("Destroy an active storage pool. This will deactivate the pool on the host, but keep any persistent config associated with it. If it has a persistent config it can later be restarted with a create() call");
        data_Pool.addMethod(method);
    }

    {
        qmf::SchemaMethod method("delete");
        method.setDesc("Destroy the pool and delete its definition");
        data_Pool.addMethod(method);
    }

    {
        qmf::SchemaMethod method("undefine");
        method.setDesc("Undefine an inactive storage pool.");
        data_Pool.addMethod(method);
    }

    {
        qmf::SchemaMethod method("createVolumeXML");
        method.setDesc("Create a storage volume within a pool based on an XML description.  Not all pool types support volume creation.");
        {
            qmf::SchemaProperty arg("xmlDesc", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("XML Description of the volume to create");
            arg.setDirection(qmf::DIR_IN);
            method.addArgument(arg);
        }

        {
            qmf::SchemaProperty arg("volume", qmf::SCHEMA_DATA_MAP);
            arg.setSubtype("reference");
            arg.setDesc("Newly created volume");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Pool.addMethod(method);
    }

    {
        qmf::SchemaMethod method("refresh");
        method.setDesc("Request that the pool refresh its list of volumes.");
        data_Pool.addMethod(method);
    }

    session.registerSchema(data_Pool);

    //
    // Data: Volume
    //
    data_Volume = qmf::Schema(SCHEMA_TYPE_DATA, package, "Volume");
    {
        qmf::SchemaProperty prop("key", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setIndex(true);
        prop.setDesc("Storage volume key");
        data_Volume.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("path", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setIndex(true);
        prop.setDesc("Storage volume path");
        data_Volume.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("name", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setIndex(true);
        prop.setDesc("Storage volume name");
        data_Volume.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("childLVMName", qmf::SCHEMA_DATA_STRING);
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("The name of the LVM pool associated with this volume, or blank of non-existant.");
        data_Volume.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("capacity", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Capacity of storage volume in bytes");
        data_Volume.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("allocation", qmf::SCHEMA_DATA_INT);
        prop.setAccess(qmf::ACCESS_READ_ONLY);
        prop.setDesc("Current allocation in bytes");
        data_Volume.addProperty(prop);
    }

    {
        qmf::SchemaProperty prop("storagePool", qmf::SCHEMA_DATA_MAP);
        prop.setSubtype("reference");
        prop.setAccess(qmf::ACCESS_READ_CREATE);
        prop.setDesc("Pool where this storage volume exists");
        data_Volume.addProperty(prop);
    }

    {
        qmf::SchemaMethod method("getXMLDesc");
        method.setDesc("Return an XML description of the volume.");
        {
            qmf::SchemaProperty arg("description", qmf::SCHEMA_DATA_STRING);
            arg.setDesc("XML description of the volume.");
            arg.setDirection(qmf::DIR_OUT);
            method.addArgument(arg);
        }

        data_Volume.addMethod(method);
    }

    {
        qmf::SchemaMethod method("delete");
        method.setDesc("Delete the storage volume from the pool.");
        data_Volume.addMethod(method);
    }

    session.registerSchema(data_Volume);

}

